Index: src/includes/admin/metaboxes.php
===================================================================
--- src/includes/admin/metaboxes.php	(revision 6055)
+++ src/includes/admin/metaboxes.php	(working copy)
@@ -25,7 +25,7 @@
 	// Forums
 	if ( current_user_can( 'publish_forums' ) ) {
 		$link       = add_query_arg( array( 'post_type' => bbp_get_forum_post_type() ), get_admin_url( null, 'edit.php' ) );
-		$text       = sprintf( _n( '%s Forum', '%s Forums', $r['forum_count'], 'bbpress' ), $r['forum_count'] );
+		$text       = sprintf( _n( '%s Forum', '%s Forums', $r['forum_count_int'], 'bbpress' ), $r['forum_count'] );
 		$elements[] = '<a href="' . esc_url( $link ) . '" class="bbp-glance-forums">' . esc_html( $text ) . '</a>';
 	}
 
@@ -32,7 +32,7 @@
 	// Topics
 	if ( current_user_can( 'publish_topics' ) ) {
 		$link       = add_query_arg( array( 'post_type' => bbp_get_topic_post_type() ), get_admin_url( null, 'edit.php' ) );
-		$text       = sprintf( _n( '%s Topic', '%s Topics', $r['topic_count'], 'bbpress' ), $r['topic_count'] );
+		$text       = sprintf( _n( '%s Topic', '%s Topics', $r['topic_count_int'], 'bbpress' ), $r['topic_count'] );
 		$elements[] = '<a href="' . esc_url( $link ) . '" class="bbp-glance-topics">' . esc_html( $text ) . '</a>';
 	}
 
@@ -39,7 +39,7 @@
 	// Replies
 	if ( current_user_can( 'publish_replies' ) ) {
 		$link       = add_query_arg( array( 'post_type' => bbp_get_reply_post_type() ), get_admin_url( null, 'edit.php' ) );
-		$text       = sprintf( _n( '%s Reply', '%s Replies', $r['reply_count'], 'bbpress' ), $r['reply_count'] );
+		$text       = sprintf( _n( '%s Reply', '%s Replies', $r['reply_count_int'], 'bbpress' ), $r['reply_count'] );
 		$elements[] = '<a href="' . esc_url( $link ) . '" class="bbp-glance-replies">' . esc_html( $text ) . '</a>';
 	}
 
@@ -46,7 +46,7 @@
 	// Topic Tags
 	if ( bbp_allow_topic_tags() && current_user_can( 'manage_topic_tags' ) ) {
 		$link       = add_query_arg( array( 'taxonomy' => bbp_get_topic_tag_tax_id(), 'post_type' => bbp_get_topic_post_type() ), get_admin_url( null, 'edit-tags.php' ) );
-		$text       = sprintf( _n( '%s Topic Tag', '%s Topic Tags', $r['topic_tag_count'], 'bbpress' ), $r['topic_tag_count'] );
+		$text       = sprintf( _n( '%s Topic Tag', '%s Topic Tags', $r['topic_tag_count_int'], 'bbpress' ), $r['topic_tag_count'] );
 		$elements[] = '<a href="' . esc_url( $link ) . '" class="bbp-glance-topic-tags">' . esc_html( $text ) . '</a>';
 	}
 
@@ -94,7 +94,7 @@
 
 				<?php
 					$num  = $r['forum_count'];
-					$text = _n( 'Forum', 'Forums', $r['forum_count'], 'bbpress' );
+					$text = _n( 'Forum', 'Forums', $r['forum_count_int'], 'bbpress' );
 					if ( current_user_can( 'publish_forums' ) ) {
 						$link = add_query_arg( array( 'post_type' => bbp_get_forum_post_type() ), get_admin_url( null, 'edit.php' ) );
 						$num  = '<a href="' . esc_url( $link ) . '">' . $num  . '</a>';
@@ -111,7 +111,7 @@
 
 				<?php
 					$num  = $r['topic_count'];
-					$text = _n( 'Topic', 'Topics', $r['topic_count'], 'bbpress' );
+					$text = _n( 'Topic', 'Topics', $r['topic_count_int'], 'bbpress' );
 					if ( current_user_can( 'publish_topics' ) ) {
 						$link = add_query_arg( array( 'post_type' => bbp_get_topic_post_type() ), get_admin_url( null, 'edit.php' ) );
 						$num  = '<a href="' . esc_url( $link ) . '">' . $num  . '</a>';
@@ -128,7 +128,7 @@
 
 				<?php
 					$num  = $r['reply_count'];
-					$text = _n( 'Reply', 'Replies', $r['reply_count'], 'bbpress' );
+					$text = _n( 'Reply', 'Replies', $r['reply_count_int'], 'bbpress' );
 					if ( current_user_can( 'publish_replies' ) ) {
 						$link = add_query_arg( array( 'post_type' => bbp_get_reply_post_type() ), get_admin_url( null, 'edit.php' ) );
 						$num  = '<a href="' . esc_url( $link ) . '">' . $num  . '</a>';
@@ -147,7 +147,7 @@
 
 					<?php
 						$num  = $r['topic_tag_count'];
-						$text = _n( 'Topic Tag', 'Topic Tags', $r['topic_tag_count'], 'bbpress' );
+						$text = _n( 'Topic Tag', 'Topic Tags', $r['topic_tag_count_int'], 'bbpress' );
 						if ( current_user_can( 'manage_topic_tags' ) ) {
 							$link = add_query_arg( array( 'taxonomy' => bbp_get_topic_tag_tax_id(), 'post_type' => bbp_get_topic_post_type() ), get_admin_url( null, 'edit-tags.php' ) );
 							$num  = '<a href="' . esc_url( $link ) . '">' . $num  . '</a>';
@@ -179,7 +179,7 @@
 
 				<?php
 					$num  = $r['user_count'];
-					$text = _n( 'User', 'Users', $r['user_count'], 'bbpress' );
+					$text = _n( 'User', 'Users', $r['user_count_int'], 'bbpress' );
 					if ( current_user_can( 'edit_users' ) ) {
 						$link = get_admin_url( null, 'users.php' );
 						$num  = '<a href="' . $link . '">' . $num  . '</a>';
@@ -198,7 +198,7 @@
 
 					<?php
 						$num  = $r['topic_count_hidden'];
-						$text = _n( 'Hidden Topic', 'Hidden Topics', $r['topic_count_hidden'], 'bbpress' );
+						$text = _n( 'Hidden Topic', 'Hidden Topics', $r['topic_count_hidden_int'], 'bbpress' );
 						$link = add_query_arg( array( 'post_type' => bbp_get_topic_post_type() ), get_admin_url( null, 'edit.php' ) );
 						if ( '0' !== $num ) {
 							$link = add_query_arg( array( 'post_status' => bbp_get_spam_status_id() ), $link );
@@ -220,7 +220,7 @@
 
 					<?php
 						$num  = $r['reply_count_hidden'];
-						$text = _n( 'Hidden Reply', 'Hidden Replies', $r['reply_count_hidden'], 'bbpress' );
+						$text = _n( 'Hidden Reply', 'Hidden Replies', $r['reply_count_hidden_int'], 'bbpress' );
 						$link = add_query_arg( array( 'post_type' => bbp_get_reply_post_type() ), get_admin_url( null, 'edit.php' ) );
 						if ( '0' !== $num ) {
 							$link = add_query_arg( array( 'post_status' => bbp_get_spam_status_id() ), $link );
@@ -242,7 +242,7 @@
 
 					<?php
 						$num  = $r['empty_topic_tag_count'];
-						$text = _n( 'Empty Topic Tag', 'Empty Topic Tags', $r['empty_topic_tag_count'], 'bbpress' );
+						$text = _n( 'Empty Topic Tag', 'Empty Topic Tags', $r['empty_topic_tag_count_int'], 'bbpress' );
 						$link = add_query_arg( array( 'taxonomy' => bbp_get_topic_tag_tax_id(), 'post_type' => bbp_get_topic_post_type() ), get_admin_url( null, 'edit-tags.php' ) );
 						$num  = '<a href="' . esc_url( $link ) . '">' . $num  . '</a>';
 						$text = '<a class="waiting" href="' . esc_url( $link ) . '">' . $text . '</a>';
Index: src/includes/common/functions.php
===================================================================
--- src/includes/common/functions.php	(revision 6055)
+++ src/includes/common/functions.php	(working copy)
@@ -452,7 +452,7 @@
  * @uses wp_count_posts() To count the number of forums, topics and replies
  * @uses wp_count_terms() To count the number of topic tags
  * @uses current_user_can() To check if the user is capable of doing things
  * @uses number_format_i18n() To format the number
  * @uses apply_filters() Calls 'bbp_get_statistics' with the statistics and args
  * @return object Walked forum tree
  */
@@ -524,14 +524,14 @@
 			// Trash
 			$topics['trashed'] = ( ! empty( $r['count_trashed_topics'] ) && current_user_can( 'view_trash'          ) ) ? (int) $all_topics->{$trash}   : 0;
 
-			// Total hidden (private + spam + trash)
+			// Total hidden (pending + private + spam + trash)
 			$topic_count_hidden = $topics['pending'] + $topics['private'] + $topics['spammed'] + $topics['trashed'];
 
 			// Generate the hidden topic count's title attribute
-			$topic_titles[] = ! empty( $topics['pending'] ) ? sprintf( __( 'Pending: %s', 'bbpress' ), number_format_i18n( $topics['pending'] ) ) : '';
-			$topic_titles[] = ! empty( $topics['private'] ) ? sprintf( __( 'Private: %s', 'bbpress' ), number_format_i18n( $topics['private'] ) ) : '';
-			$topic_titles[] = ! empty( $topics['spammed'] ) ? sprintf( __( 'Spammed: %s', 'bbpress' ), number_format_i18n( $topics['spammed'] ) ) : '';
-			$topic_titles[] = ! empty( $topics['trashed'] ) ? sprintf( __( 'Trashed: %s', 'bbpress' ), number_format_i18n( $topics['trashed'] ) ) : '';
+			$topic_titles[] = ! empty( $topics['pending'] ) ? sprintf( __( 'Pending: %s', 'bbpress' ), bbp_number_format_i18n( $topics['pending'] ) ) : '';
+			$topic_titles[] = ! empty( $topics['private'] ) ? sprintf( __( 'Private: %s', 'bbpress' ), bbp_number_format_i18n( $topics['private'] ) ) : '';
+			$topic_titles[] = ! empty( $topics['spammed'] ) ? sprintf( __( 'Spammed: %s', 'bbpress' ), bbp_number_format_i18n( $topics['spammed'] ) ) : '';
+			$topic_titles[] = ! empty( $topics['trashed'] ) ? sprintf( __( 'Trashed: %s', 'bbpress' ), bbp_number_format_i18n( $topics['trashed'] ) ) : '';
 
 			// Compile the hidden topic title
 			$hidden_topic_title = implode( ' | ', array_filter( $topic_titles ) );
@@ -560,14 +560,14 @@
 			// Trash
 			$replies['trashed'] = ( ! empty( $r['count_trashed_replies'] ) && current_user_can( 'view_trash'           ) ) ? (int) $all_replies->{$trash}   : 0;
 
-			// Total hidden (private + spam + trash)
+			// Total hidden (pending + private + spam + trash)
 			$reply_count_hidden = $replies['pending'] + $replies['private'] + $replies['spammed'] + $replies['trashed'];
 
 			// Generate the hidden topic count's title attribute
-			$reply_titles[] = ! empty( $replies['pending'] ) ? sprintf( __( 'Pending: %s', 'bbpress' ), number_format_i18n( $replies['pending'] ) ) : '';
-			$reply_titles[] = ! empty( $replies['private'] ) ? sprintf( __( 'Private: %s', 'bbpress' ), number_format_i18n( $replies['private'] ) ) : '';
-			$reply_titles[] = ! empty( $replies['spammed'] ) ? sprintf( __( 'Spammed: %s', 'bbpress' ), number_format_i18n( $replies['spammed'] ) ) : '';
-			$reply_titles[] = ! empty( $replies['trashed'] ) ? sprintf( __( 'Trashed: %s', 'bbpress' ), number_format_i18n( $replies['trashed'] ) ) : '';
+			$reply_titles[] = ! empty( $replies['pending'] ) ? sprintf( __( 'Pending: %s', 'bbpress' ), bbp_number_format_i18n( $replies['pending'] ) ) : '';
+			$reply_titles[] = ! empty( $replies['private'] ) ? sprintf( __( 'Private: %s', 'bbpress' ), bbp_number_format_i18n( $replies['private'] ) ) : '';
+			$reply_titles[] = ! empty( $replies['spammed'] ) ? sprintf( __( 'Spammed: %s', 'bbpress' ), bbp_number_format_i18n( $replies['spammed'] ) ) : '';
+			$reply_titles[] = ! empty( $replies['trashed'] ) ? sprintf( __( 'Trashed: %s', 'bbpress' ), bbp_number_format_i18n( $replies['trashed'] ) ) : '';
 
 			// Compile the hidden replies title
 			$hidden_reply_title = implode( ' | ', array_filter( $reply_titles ) );
@@ -588,7 +588,7 @@
 	}
 
 	// Tally the tallies
-	$statistics = array_map( 'number_format_i18n', array_map( 'absint', compact(
+	$counts = array_map( 'absint', compact(
 		'user_count',
 		'forum_count',
 		'topic_count',
@@ -597,8 +597,14 @@
 		'reply_count_hidden',
 		'topic_tag_count',
 		'empty_topic_tag_count'
-	) ) );
+	) );
 
+	// Loop through and store the integer and i18n formatted counts.
+	foreach ( $counts as $key => $count ) {
+		$statistics[ $key ]         = bbp_number_format_i18n( $count );
+		$statistics[ "{$key}_int" ] = $count;
+	}
+
 	// Add the hidden (topic/reply) count title attribute strings because we
 	// don't need to run the math functions on these (see above)
 	$statistics['hidden_topic_title'] = isset( $hidden_topic_title ) ? $hidden_topic_title : '';
@@ -452,7 +452,7 @@
  * @uses wp_count_terms() To count the number of topic tags
  * @uses current_user_can() To check if the user is capable of doing things
- * @uses number_format_i18n() To format the number
+ * @uses bbp_number_format_i18n() To format the number
  * @uses apply_filters() Calls 'bbp_get_statistics' with the statistics and args
  * @return object Walked forum tree
